bayespy.nodes.GaussianGammaARD.broadcasting_multiplier
======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGammaARD.broadcasting_multiplier